Cauchy Distribution
Usage
Cauchy(location = 0, scale = 1)
# S4 method for class 'Cauchy,numeric'
d(distr, x)
# S4 method for class 'Cauchy,numeric'
p(distr, x)
# S4 method for class 'Cauchy,numeric'
qn(distr, x)
# S4 method for class 'Cauchy,numeric'
r(distr, n)
# S4 method for class 'Cauchy'
mean(x)
# S4 method for class 'Cauchy'
median(x)
# S4 method for class 'Cauchy'
mode(x)
# S4 method for class 'Cauchy'
var(x)
# S4 method for class 'Cauchy'
sd(x)
# S4 method for class 'Cauchy'
skew(x)
# S4 method for class 'Cauchy'
kurt(x)
# S4 method for class 'Cauchy'
entro(x)
# S4 method for class 'Cauchy'
finf(x)
llcauchy(x, location, scale)
# S4 method for class 'Cauchy,numeric'
ll(distr, x)
ecauchy(x, type = "mle", ...)
# S4 method for class 'Cauchy,numeric'
mle(
distr,
x,
par0 = "me",
method = "L-BFGS-B",
lower = c(-Inf, 1e-05),
upper = c(Inf, Inf)
)
# S4 method for class 'Cauchy,numeric'
me(distr, x)
vcauchy(location, scale, type = "mle")
# S4 method for class 'Cauchy'
avar_mle(distr)Arguments
- location, scale
numeric. The distribution parameters.
- distr
an object of class
Cauchy.- x
an object of class
Cauchy. If the function also has adistrargument,xis a numeric vector, a sample of observations.- n
numeric. The sample size.
- type
character, case ignored. The estimator type (mle, me, or same).
- ...
extra arguments.
- par0, method, lower, upper
arguments passed to optim.
Value
Each type of function returns a different type of object:
Distribution Functions: When supplied with one argument (
distr), thed(),p(),q(),r(),ll()functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distrandx), they evaluate the aforementioned functions directly.Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The
moments()function returns a list with all the available methods.Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.
Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.