Dirichlet Distribution
Usage
Dir(alpha = c(1, 1))
# S4 method for class 'Dir,numeric'
d(distr, x)
# S4 method for class 'Dir,numeric'
r(distr, n)
# S4 method for class 'Dir'
mean(x)
# S4 method for class 'Dir'
mode(x)
# S4 method for class 'Dir'
var(x)
# S4 method for class 'Dir'
entro(x)
# S4 method for class 'Dir'
finf(x)
lldirichlet(x, alpha)
# S4 method for class 'Dir,matrix'
ll(distr, x)
edirichlet(x, type = "mle", ...)
# S4 method for class 'Dir,matrix'
mle(distr, x, par0 = "same", method = "L-BFGS-B", lower = 1e-05, upper = Inf)
# S4 method for class 'Dir,matrix'
me(distr, x)
# S4 method for class 'Dir,matrix'
same(distr, x)
vdirichlet(alpha, type = "mle")
# S4 method for class 'Dir'
avar_mle(distr)
# S4 method for class 'Dir'
avar_me(distr)
# S4 method for class 'Dir'
avar_same(distr)Arguments
- alpha
numeric. The distribution parameters.
- distr
an object of class
Dir.- x
an object of class
Dir. If the function also has adistrargument,xis a numeric vector, a sample of observations.- n
numeric. The sample size.
- type
character, case ignored. The estimator type (mle, me, or same).
- ...
extra arguments.
- par0, method, lower, upper
arguments passed to optim.
Value
Each type of function returns a different type of object:
Distribution Functions: When supplied with one argument (
distr), thed(),p(),q(),r(),ll()functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distrandx), they evaluate the aforementioned functions directly.Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The
moments()function returns a list with all the available methods.Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.
Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.