Skip to contents

Fisher Distribution

Usage

Fisher(df1 = 1, df2 = 1)

# S4 method for class 'Fisher,numeric'
d(distr, x)

# S4 method for class 'Fisher,numeric'
p(distr, x)

# S4 method for class 'Fisher,numeric'
qn(distr, x)

# S4 method for class 'Fisher,numeric'
r(distr, n)

# S4 method for class 'Fisher'
mean(x)

# S4 method for class 'Fisher'
median(x)

# S4 method for class 'Fisher'
mode(x)

# S4 method for class 'Fisher'
var(x)

# S4 method for class 'Fisher'
sd(x)

# S4 method for class 'Fisher'
skew(x)

# S4 method for class 'Fisher'
kurt(x)

# S4 method for class 'Fisher'
entro(x)

llf(x, df1, df2)

# S4 method for class 'Fisher,numeric'
ll(distr, x)

Arguments

df1, df2

numeric. The distribution parameters.

distr

an object of class Fisher.

x

an object of class Fisher. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.