Gamma Distribution
Usage
Multigam(shape = 1, scale = 1)
dmultigam(x, shape, scale, log = FALSE)
rmultigam(n, shape, scale)
# S4 method for class 'Multigam,numeric'
d(distr, x)
# S4 method for class 'Multigam,numeric'
r(distr, n)
# S4 method for class 'Multigam'
mean(x)
# S4 method for class 'Multigam'
var(x)
# S4 method for class 'Multigam'
finf(x)
llmultigam(x, shape, scale)
# S4 method for class 'Multigam,matrix'
ll(distr, x)
emultigam(x, type = "mle", ...)
# S4 method for class 'Multigam,matrix'
mle(distr, x, par0 = "same", method = "L-BFGS-B", lower = 1e-05, upper = Inf)
# S4 method for class 'Multigam,matrix'
me(distr, x)
# S4 method for class 'Multigam,matrix'
same(distr, x)
vmultigam(shape, scale, type = "mle")
# S4 method for class 'Multigam'
avar_mle(distr)
# S4 method for class 'Multigam'
avar_me(distr)
# S4 method for class 'Multigam'
avar_same(distr)Arguments
- shape, scale
numeric. The distribution parameters.
- x
an object of class
Multigam. If the function also has adistrargument,xis a numeric vector, a sample of observations.- log
logical. Should the log of the density be returned?
- n
numeric. The sample size.
- distr
an object of class
Multigam.- type
character, case ignored. The estimator type (mle, me, or same).
- ...
extra arguments.
- par0, method, lower, upper
arguments passed to optim.
Value
Each type of function returns a different type of object:
Distribution Functions: When supplied with one argument (
distr), thed(),p(),q(),r(),ll()functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distrandx), they evaluate the aforementioned functions directly.Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The
moments()function returns a list with all the available methods.Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.
Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.