Skip to contents

Normal Distribution

Usage

Norm(mean = 0, sd = 1)

# S4 method for class 'Norm,numeric'
d(distr, x)

# S4 method for class 'Norm,numeric'
p(distr, x)

# S4 method for class 'Norm,numeric'
qn(distr, x)

# S4 method for class 'Norm,numeric'
r(distr, n)

# S4 method for class 'Norm'
mean(x)

# S4 method for class 'Norm'
median(x)

# S4 method for class 'Norm'
mode(x)

# S4 method for class 'Norm'
var(x)

# S4 method for class 'Norm'
sd(x)

# S4 method for class 'Norm'
skew(x)

# S4 method for class 'Norm'
kurt(x)

# S4 method for class 'Norm'
entro(x)

# S4 method for class 'Norm'
finf(x)

llnorm(x, mean, sd)

# S4 method for class 'Norm,numeric'
ll(distr, x)

enorm(x, type = "mle", ...)

# S4 method for class 'Norm,numeric'
mle(distr, x)

# S4 method for class 'Norm,numeric'
me(distr, x)

vnorm(mean, sd, type = "mle")

# S4 method for class 'Norm'
avar_mle(distr)

# S4 method for class 'Norm'
avar_me(distr)

Arguments

mean, sd

numeric. The distribution parameters.

distr

an object of class Norm.

x

an object of class Norm. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

type

character, case ignored. The estimator type (mle, me, or same).

...

extra arguments.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.