Skip to contents

Poisson Distribution

Usage

Pois(lambda = 1)

# S4 method for class 'Pois,numeric'
d(distr, x)

# S4 method for class 'Pois,numeric'
p(distr, x)

# S4 method for class 'Pois,numeric'
qn(distr, x)

# S4 method for class 'Pois,numeric'
r(distr, n)

# S4 method for class 'Pois'
mean(x)

# S4 method for class 'Pois'
median(x)

# S4 method for class 'Pois'
mode(x)

# S4 method for class 'Pois'
var(x)

# S4 method for class 'Pois'
sd(x)

# S4 method for class 'Pois'
skew(x)

# S4 method for class 'Pois'
kurt(x)

# S4 method for class 'Pois'
entro(x)

# S4 method for class 'Pois'
finf(x)

llpois(x, lambda)

# S4 method for class 'Pois,numeric'
ll(distr, x)

epois(x, type = "mle", ...)

# S4 method for class 'Pois,numeric'
mle(distr, x)

# S4 method for class 'Pois,numeric'
me(distr, x)

vpois(lambda, type = "mle")

# S4 method for class 'Pois'
avar_mle(distr)

# S4 method for class 'Pois'
avar_me(distr)

Arguments

lambda

numeric. The distribution parameters.

distr

an object of class Pois.

x

an object of class Pois. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

type

character, case ignored. The estimator type (mle, me, or same).

...

extra arguments.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.