Skip to contents

Student Distribution

Usage

Stud(df = 1)

# S4 method for class 'Stud,numeric'
d(distr, x)

# S4 method for class 'Stud,numeric'
p(distr, x)

# S4 method for class 'Stud,numeric'
qn(distr, x)

# S4 method for class 'Stud,numeric'
r(distr, n)

# S4 method for class 'Stud'
mean(x)

# S4 method for class 'Stud'
median(x)

# S4 method for class 'Stud'
mode(x)

# S4 method for class 'Stud'
var(x)

# S4 method for class 'Stud'
sd(x)

# S4 method for class 'Stud'
skew(x)

# S4 method for class 'Stud'
kurt(x)

# S4 method for class 'Stud'
entro(x)

llt(x, df)

# S4 method for class 'Stud,numeric'
ll(distr, x)

Arguments

df

numeric. The distribution parameter.

distr

an object of class Stud.

x

an object of class Stud. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.