Skip to contents

Uniform Distribution

Usage

Unif(min = 0, max = 1)

# S4 method for class 'Unif,numeric'
d(distr, x)

# S4 method for class 'Unif,numeric'
p(distr, x)

# S4 method for class 'Unif,numeric'
qn(distr, x)

# S4 method for class 'Unif,numeric'
r(distr, n)

# S4 method for class 'Unif'
mean(x)

# S4 method for class 'Unif'
median(x)

# S4 method for class 'Unif'
mode(x)

# S4 method for class 'Unif'
var(x)

# S4 method for class 'Unif'
sd(x)

# S4 method for class 'Unif'
skew(x)

# S4 method for class 'Unif'
kurt(x)

# S4 method for class 'Unif'
entro(x)

llunif(x, min, max)

# S4 method for class 'Unif,numeric'
ll(distr, x)

eunif(x, type = "mle", ...)

# S4 method for class 'Unif,numeric'
mle(distr, x)

# S4 method for class 'Unif,numeric'
me(distr, x)

Arguments

min, max

numeric. The distribution parameters.

distr

an object of class Unif.

x

an object of class Unif. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

type

character, case ignored. The estimator type (mle, me, or same).

...

extra arguments.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.