Skip to contents

Weibull Distribution

Usage

Weib(shape = 1, scale = 1)

# S4 method for class 'Weib,numeric'
d(distr, x)

# S4 method for class 'Weib,numeric'
p(distr, x)

# S4 method for class 'Weib,numeric'
qn(distr, x)

# S4 method for class 'Weib,numeric'
r(distr, n)

# S4 method for class 'Weib'
mean(x)

# S4 method for class 'Weib'
median(x)

# S4 method for class 'Weib'
mode(x)

# S4 method for class 'Weib'
var(x)

# S4 method for class 'Weib'
sd(x)

# S4 method for class 'Weib'
skew(x)

# S4 method for class 'Weib'
kurt(x)

# S4 method for class 'Weib'
entro(x)

llweib(x, shape, scale)

# S4 method for class 'Weib,numeric'
ll(distr, x)

eweib(x, type = "mle", ...)

# S4 method for class 'Weib,numeric'
mle(distr, x, par0 = "same", method = "L-BFGS-B", lower = 1e-05, upper = Inf)

# S4 method for class 'Weib,numeric'
me(distr, x)

# S4 method for class 'Weib,numeric'
same(distr, x)

vweib(shape, scale, type = "mle")

# S4 method for class 'Weib'
avar_mle(distr)

# S4 method for class 'Weib'
avar_me(distr)

# S4 method for class 'Weib'
avar_same(distr)

Arguments

shape, scale

numeric. The distribution parameters.

distr

an object of class Weib.

x

an object of class Weib. If the function also has a distr argument, x is a numeric vector, a sample of observations.

n

numeric. The sample size.

type

character, case ignored. The estimator type (mle, me, or same).

...

extra arguments.

par0, method, lower, upper

arguments passed to optim.

Value

Each type of function returns a different type of object:

  • Distribution Functions: When supplied with one argument (distr), the d(), p(), q(), r(), ll() functions return the density, cumulative probability, quantile, random sample generator, and log-likelihood functions, respectively. When supplied with both arguments (distr and x), they evaluate the aforementioned functions directly.

  • Moments: Returns a numeric, either vector or matrix depending on the moment and the distribution. The moments() function returns a list with all the available methods.

  • Estimation: Returns a list. The estimator of the unknown parameters. Note that in distribution families like the binomial, multinomial, and negative binomial, the size is not returned, since it is considered known.

  • Variance: Returns a named matrix. The asymptotic covariance matrix of the estimator.